pub struct LambdaService { /* private fields */ }Implementations
Sourceimpl LambdaService
impl LambdaService
pub fn new(state: SharedLambdaState) -> Self
pub fn with_s3_delivery(self, s3: Arc<dyn S3Delivery>) -> Self
pub fn with_runtime(self, runtime: Arc<ContainerRuntime>) -> Self
pub fn with_snapshot_store(self, store: Arc<dyn SnapshotStore>) -> Self
pub fn with_delivery_bus(self, bus: Arc<DeliveryBus>) -> Self
pub fn with_role_trust_validator( self, validator: Arc<dyn RoleTrustValidator>, ) -> Self
Sourcepub fn snapshot_hook(&self) -> Option<SnapshotHook>
pub fn snapshot_hook(&self) -> Option<SnapshotHook>
Build a hook that persists the current Lambda state when invoked, or
None in memory mode (no snapshot store). The CloudFormation provisioner
mutates state directly and uses this to write a CFN-provisioned
function through to disk, the same way a direct mutating API call would.